-- Quicke_QBZange
-- Specialization for Quicke_QBZange mod
--
-- @author  Tobias F. (John Deere 6930, 1. LS-Modschmiede)

Quicke_QBZange = {};

function Quicke_QBZange.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Attachable, specializations);
end;

function Quicke_QBZange:load(xmlFile)

	local Collision1 = {};
	Collision1.collision = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.collision1#collision"));
	Collision1.collisionAttacher = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.collision1#collsionAttacher"));
	Collision1.armAttacher = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.collision1#armAttacher"));
	Collision1.index = 0;
	self.Collision1Base = Collision1;
	
	local Collision2 = {};
	Collision2.collision = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.collision2#collision"));
	Collision2.collisionAttacher = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.collision2#collsionAttacher"));
	Collision2.armAttacher = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.collision2#armAttacher"));
	Collision2.index = 0;
	self.Collision2Base = Collision2;

	self.collisions = true;
	
	local Trans1Node = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.Trans1#index"));
    if Trans1Node ~= nil then
        self.Trans1 = {};
        self.Trans1.node = Trans1Node;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.Trans1#minTrans"));
        self.Trans1.minTrans = {};
        self.Trans1.minTrans[1] = Utils.getNoNil(x, 0);
        self.Trans1.minTrans[2] = Utils.getNoNil(y, 0);
        self.Trans1.minTrans[3] = Utils.getNoNil(z, 0);

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.Trans1#maxTrans"));
        self.Trans1.maxTrans = {};
        self.Trans1.maxTrans[1] = Utils.getNoNil(x, 0);
        self.Trans1.maxTrans[2] = Utils.getNoNil(y, 0);
        self.Trans1.maxTrans[3] = Utils.getNoNil(z, 0);

        self.Trans1.transTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.Trans1#transTime"), 2)*1000;
        self.Trans1.touchTransLimit = Utils.getNoNil(getXMLString(xmlFile, "vehicle.Trans1#touchTransLimit"), 10);
    end;
	local Trans2Node = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.Trans2#index"));
    if Trans2Node ~= nil then
        self.Trans2 = {};
        self.Trans2.node = Trans2Node;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.Trans2#minTrans"));
        self.Trans2.minTrans = {};
        self.Trans2.minTrans[1] = Utils.getNoNil(x, 0);
        self.Trans2.minTrans[2] = Utils.getNoNil(y, 0);
        self.Trans2.minTrans[3] = Utils.getNoNil(z, 0);

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.Trans2#maxTrans"));
        self.Trans2.maxTrans = {};
        self.Trans2.maxTrans[1] = Utils.getNoNil(x, 0);
        self.Trans2.maxTrans[2] = Utils.getNoNil(y, 0);
        self.Trans2.maxTrans[3] = Utils.getNoNil(z, 0);

        self.Trans2.transTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.Trans2#transTime"), 2)*1000;
        self.Trans2.touchTransLimit = Utils.getNoNil(getXMLString(xmlFile, "vehicle.Trans2#touchTransLimit"), 10);
    end;
    
	self.keys = {};
	self.keysDesc = {};
    local i=0;
    while true do
        local baseName = string.format("vehicle.keys.input(%d)", i);
        local inputName = getXMLString(xmlFile, baseName.. "#name");
        if inputName == nil then
            break;
        end;
        local inputKey = getXMLString(xmlFile, baseName.. "#key");
        if Input[inputKey] == nil then
            print("Error: invalid key '" .. inputKey .. "'  for input event '" .. inputName .. "'");
            break;
        end;
        self.keys[inputName] = Input[inputKey];
		self.keysDesc[inputName] = getXMLString(xmlFile, baseName.. "#keyDesc");
        i = i+1;
    end;
end;

function Quicke_QBZange:delete()
end;

function Quicke_QBZange:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Quicke_QBZange:keyEvent(unicode, sym, modifier, isDown)
end;

function Quicke_QBZange:update(dt)
	local CollisionBase1 = self.Collision1Base;
	setJointFrame(CollisionBase1.index, 0, CollisionBase1.armAttacher);
	local CollisionBase2 = self.Collision2Base;
	setJointFrame(CollisionBase2.index, 0, CollisionBase2.armAttacher);

    if self.collisions then
		self.collisions = false;
		local constr = JointConstructor:new();
		constr:setActors(self.rootNode, self.Collision1Base.collision);
		constr:setJointTransforms(self.Collision1Base.armAttacher, self.Collision1Base.collisionAttacher);
		for i=1, 3 do
			constr:setRotationLimit(i-1, 0, 0, 0);
			constr:setTranslationLimit(i-1, true, 0, 0);
		end;
		self.Collision1Base.index = constr:finalize();

		local constr2 = JointConstructor:new();
		constr2:setActors(self.rootNode, self.Collision2Base.collision);
		constr2:setJointTransforms(self.Collision2Base.armAttacher, self.Collision2Base.collisionAttacher);
		for i=1, 3 do
			constr2:setRotationLimit(i-1, 0, 0, 0);
			constr2:setTranslationLimit(i-1, true, 0, 0);
		end;
		self.Collision2Base.index = constr2:finalize();
	end;
	if self.attacherVehicle ~= nil then
	    if self:getIsActiveForInput() then
			if Input.isKeyPressed(self.keys.OPEN_PLIERS) then
				local x, y, z = getTranslation(self.Trans1.node);
		        local trans = {x,y,z};
		        local newTrans = Utils.getMovedLimitedValues(trans, self.Trans1.maxTrans, self.Trans1.minTrans, 3, self.Trans1.transTime, dt, true);
		        setTranslation(self.Trans1.node, unpack(newTrans));
				local x, y, z = getTranslation(self.Trans2.node);
		        local trans = {x,y,z};
		        local newTrans = Utils.getMovedLimitedValues(trans, self.Trans2.maxTrans, self.Trans2.minTrans, 3, self.Trans2.transTime, dt, true);
		        setTranslation(self.Trans2.node, unpack(newTrans));
		    end;

			if Input.isKeyPressed(self.keys.CLOSE_PLIERS) then
				local x, y, z = getTranslation(self.Trans1.node);
		        local trans = {x,y,z};
		        local newTrans = Utils.getMovedLimitedValues(trans, self.Trans1.maxTrans, self.Trans1.minTrans, 3, self.Trans1.transTime, dt, false);
		        setTranslation(self.Trans1.node, unpack(newTrans));
				local x, y, z = getTranslation(self.Trans2.node);
		        local trans = {x,y,z};
		        local newTrans = Utils.getMovedLimitedValues(trans, self.Trans2.maxTrans, self.Trans2.minTrans, 3, self.Trans2.transTime, dt, false);
		        setTranslation(self.Trans2.node, unpack(newTrans));
		    end;
		end;
	end;
end;

function Quicke_QBZange:draw()
			g_currentMission:addExtraPrintText("Tasto: " .. self.keysDesc.OPEN_PLIERS .. "Apri pinze");
			g_currentMission:addExtraPrintText("Tasto: " .. self.keysDesc.CLOSE_PLIERS .. "Kiudi pinze");

end;